.. _util:

Utilities
=========

URI Functions
-------------

.. automodule:: falcon.uri
    :members: encode, encode_value, decode, parse_host,
        parse_query_string, unquote_string

Miscellaneous
-------------

.. automodule:: falcon
    :members: deprecated, http_now, dt_to_http, http_date_to_dt,
        to_query_str, get_http_status, get_bound_method

.. autoclass:: falcon.TimezoneGMT
    :members:
